function [B,Bd] = BM_Estimate(S,k)

% [B,Bd] = BM_Estimate(S,k)
%
% This function implements the maximum likelihood estimation for parameters
% of the k:th order Markovian background model. Optimal parameters are 
% estimated from a set of seqences given in matrix S (rows correspond to
% sequences).
%
% INPUT:
% S       - A matrix of size N-by-L consisting of integers between 1 and 4.
%           N is the number of sequences, L denotes the length of the 
%           sequences. Thus, S(i,:) encodes the i:th sequence. Base pairs 
%           are coded using integers as follows: A = 1, C = 2, G = 3, and 
%           T = 4.
% k       - An interger (0,1,2,...) specifying the order of the Markovian 
%           background model.
%
% OUTPUT:
% B       - Estimated counts.
% [Bd]    - Optional. Estimated parameters.

% 12/10/2006 by Harri Lhdesmki

% Initialize output.
B = zeros(4^k,4);
[Bd1,Bd2] = size(B);

[N,L] = size(S);

b = 4.^[k-1:-1:0]';
SS = S - 1; % Values between 0 and 3.
k_1 = k - 1;
%edges = [0.5:1:Bd1*Bd2+0.5];
%bins = [1:Bd1*Bd2];

for i=1:L-k
  ind = sub2ind([Bd1,Bd2],SS(:,i:i+k_1)*b+1,S(:,i+k));
  for i=1:length(ind)
    B(ind(i)) = B(ind(i)) + 1;
  end
  %n = histc(ind,edges);
  %B(bins) = B(bins) + n(1:end-1)';
end

if nargout==2
  for i=1:Bd1
    Bd(i,:) = B(i,:)/sum(B(i,:));
  end
end
