function [N0,N1] = SequenceCounts(S,I0,I1,k,l,offset)

% Compute sequence counts for the Bayesian sequence inference.
%
% S       - A sequence.
% I0      - Starting & ending indices of background chunks.
% I1      - Starting & ending indices of motif.
% k       - Order of Markovian background model.
% l       - Length of motif.
% offset  - An optional parameter specifying the offset of the promoter 
%           start site.

% 17/10/2006 by Harri Lhdesmki

nb = size(I0,1);
nm = size(I1,1);
b = 4.^[k-1:-1:0]';
N0 = zeros(4^k,4);
N1 = zeros(4,l);

SS = S - 1;

for i=1:nb
  for j=(I0(i,1)+offset):(I0(i,2)+offset)
    x = SS(j-k:j-1)*b + 1;
    y = S(j);
    N0(x,y) = N0(x,y) + 1;
  end
end

for i=1:nm
  for j=(I1(i,1)+offset):(I1(i,2)+offset)
    N1(S(j),j-I1(i,1)-offset+1) = N1(S(j),j-I1(i,1)-offset+1) + 1;
  end
end
